# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .anti_affinity_group import *
from .block_storage_volume import *
from .block_storage_volume_snapshot import *
from .compute_instance import *
from .database import *
from .domain import *
from .domain_record import *
from .elastic_ip import *
from .get_anti_affinity_group import *
from .get_block_storage_volume import *
from .get_block_storage_volume_snapshot import *
from .get_compute_instance import *
from .get_compute_instance_list import *
from .get_database_uri import *
from .get_domain import *
from .get_domain_record import *
from .get_elastic_ip import *
from .get_iam_api_key import *
from .get_iam_org_policy import *
from .get_iam_role import *
from .get_instance_pool import *
from .get_instance_pool_list import *
from .get_nlb import *
from .get_nlb_service_list import *
from .get_private_network import *
from .get_security_group import *
from .get_sks_cluster import *
from .get_sks_cluster_list import *
from .get_sks_nodepool import *
from .get_sks_nodepool_list import *
from .get_sos_bucket_policy import *
from .get_template import *
from .get_zones import *
from .iam_access_key import *
from .iam_api_key import *
from .iam_org_policy import *
from .iam_role import *
from .instance_pool import *
from .nlb import *
from .nlb_service import *
from .private_network import *
from .provider import *
from .security_group import *
from .security_group_rule import *
from .sks_cluster import *
from .sks_kubeconfig import *
from .sks_nodepool import *
from .sos_bucket_policy import *
from .ssh_key import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_exoscale.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumiverse_exoscale.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "exoscale",
  "mod": "index/antiAffinityGroup",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/antiAffinityGroup:AntiAffinityGroup": "AntiAffinityGroup"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/blockStorageVolume",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/blockStorageVolume:BlockStorageVolume": "BlockStorageVolume"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/blockStorageVolumeSnapshot",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/blockStorageVolumeSnapshot:BlockStorageVolumeSnapshot": "BlockStorageVolumeSnapshot"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/computeInstance",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/computeInstance:ComputeInstance": "ComputeInstance"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/database",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/database:Database": "Database"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/domain",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/domainRecord",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/domainRecord:DomainRecord": "DomainRecord"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/elasticIp",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/elasticIp:ElasticIp": "ElasticIp"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/iamAccessKey",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/iamAccessKey:IamAccessKey": "IamAccessKey"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/iamApiKey",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/iamApiKey:IamApiKey": "IamApiKey"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/iamOrgPolicy",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/iamOrgPolicy:IamOrgPolicy": "IamOrgPolicy"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/iamRole",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/iamRole:IamRole": "IamRole"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/instancePool",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/instancePool:InstancePool": "InstancePool"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/nlb",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/nlb:Nlb": "Nlb"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/nlbService",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/nlbService:NlbService": "NlbService"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/privateNetwork",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/privateNetwork:PrivateNetwork": "PrivateNetwork"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/securityGroup",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/securityGroupRule",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/securityGroupRule:SecurityGroupRule": "SecurityGroupRule"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/sksCluster",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/sksCluster:SksCluster": "SksCluster"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/sksKubeconfig",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/sksKubeconfig:SksKubeconfig": "SksKubeconfig"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/sksNodepool",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/sksNodepool:SksNodepool": "SksNodepool"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/sosBucketPolicy",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/sosBucketPolicy:SosBucketPolicy": "SosBucketPolicy"
  }
 },
 {
  "pkg": "exoscale",
  "mod": "index/sshKey",
  "fqn": "pulumiverse_exoscale",
  "classes": {
   "exoscale:index/sshKey:SshKey": "SshKey"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "exoscale",
  "token": "pulumi:providers:exoscale",
  "fqn": "pulumiverse_exoscale",
  "class": "Provider"
 }
]
"""
)
